@@ -25,7 +25,7 @@ SMOOTH_FACTOR = 0.95
 
 def train_fn(loader, model, optimizer, loss_fn, scaler, device):
     loop = tqdm(loader)
-    smoothed_loss = None
+    smooth_loss = None
 
     for batch_idx, (data, targets) in enumerate(loop):
         data = data.to(device=device)
@@ -43,9 +43,11 @@ def train_fn(loader, model, optimizer, loss_fn, scaler, device):
         scaler.update()
 
         # update tqdm loop
-        if smoothed_loss is None:
-            smoothed_loss = loss.item()
-        loop.set_postfix(loss=loss.item(), smoothed=smoothed_loss * SMOOTH_FACTOR + loss.item())
+        loss = loss.item()
+        if smooth_loss is None:
+            smooth_loss = loss
+        smooth_loss = SMOOTH_FACTOR * smooth_loss + (1-SMOOTH_FACTOR) * loss
+        loop.set_postfix(loss=loss, smooth_loss=smooth_loss)
 
 
 def loop_fn(model, optimizer, loss_fn, trainset, valset, batch_size, max_patience=10, checkpoint=None):
